import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";

ColorPicker = class(Turbine.UI.Lotro.Window);

function ColorPicker:Constructor(parent, callback, currentColor)
	Turbine.UI.Lotro.Window.Constructor( self );

      -- set size of window	
	self.width = 400;
	self.height = 240;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();

	-- set the default window settings
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( colorPickerTitleString );
	self:SetOpacity( 1 );
	self:SetVisible(true);
	
	self.currentColor = currentColor;
	self.parent = parent;
	
	-- color label --
	self.BackColorBox = Turbine.UI.Label();
   self.BackColorBox:SetSize(50,50);
   self.BackColorBox:SetPosition(175,40);
   self.BackColorBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.BackColorBox:SetParent(self);
   self.BackColorBox:SetBackColor(currentColor);
   self.BackColorBox:SetVisible(true);

   -- the RED slider -- 
   -- label
   self.rSlidersLabel  = Turbine.UI.Label();
   self.rSlidersLabel:SetSize(50,20);
   self.rSlidersLabel:SetPosition(20,100);
   self.rSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.rSlidersLabel:SetParent(self);
   self.rSlidersLabel:SetText(redString);
   self.rSlidersLabel:SetVisible(true);  
   
   -- slider		
	self.rScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.rScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.rScrollBar:SetSize( 320, 10 );
	self.rScrollBar:SetPosition ( 70, 105);	
	self.rScrollBar:SetMinimum(0);
	self.rScrollBar:SetMaximum(256);
	self.rScrollBar:SetValue(currentColor.R * 256);
	self.rScrollBar:SetParent(self);

   -- the GREEN slider -- 
   -- label
   self.gSlidersLabel  = Turbine.UI.Label();
   self.gSlidersLabel:SetSize(50,20);
   self.gSlidersLabel:SetPosition(20,120);
   self.gSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.gSlidersLabel:SetParent(self);
   self.gSlidersLabel:SetText(greenString);
   self.gSlidersLabel:SetVisible(true);  
   
   -- slider		
	self.gScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.gScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.gScrollBar:SetSize( 320, 10 );
	self.gScrollBar:SetPosition ( 70, 125);	
	self.gScrollBar:SetMinimum(0);
	self.gScrollBar:SetMaximum(256);
	self.gScrollBar:SetValue(currentColor.G * 256);
	self.gScrollBar:SetParent(self);

   -- the BLUE slider -- 
   -- label
   self.bSlidersLabel  = Turbine.UI.Label();
   self.bSlidersLabel:SetSize(50,20);
   self.bSlidersLabel:SetPosition(20,140);
   self.bSlidersLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.bSlidersLabel:SetParent(self);
   self.bSlidersLabel:SetText(blueString);
   self.bSlidersLabel:SetVisible(true);  
   
   -- slider		
	self.bScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.bScrollBar:SetOrientation( Turbine.UI.Orientation.Horizontal );	
	self.bScrollBar:SetSize( 320, 10 );
	self.bScrollBar:SetPosition ( 70, 145);	
	self.bScrollBar:SetMinimum(0);
	self.bScrollBar:SetMaximum(256);
	self.bScrollBar:SetValue(currentColor.B * 256);
	self.bScrollBar:SetParent(self);
	
	-- accept button --
	self.acceptButton = Turbine.UI.Lotro.Button();
	self.acceptButton:SetSize( 120,40);
	self.acceptButton:SetPosition( 150,165);
	self.acceptButton:SetParent(self);
	self.acceptButton:SetText(acceptString);
	
	--[[ event handlers ]]--
	
	self.rScrollBar.ValueChanged = function(sender,args)
	  currentColor.R = self.rScrollBar:GetValue() / 256;
	  self.BackColorBox:SetBackColor(currentColor);
	end
   	
	self.gScrollBar.ValueChanged = function(sender,args)
	  currentColor.G = self.gScrollBar:GetValue() / 256;
	  self.BackColorBox:SetBackColor(currentColor);
	end
	
	self.bScrollBar.ValueChanged = function(sender,args)
	  currentColor.B = self.bScrollBar:GetValue() / 256;
	  self.BackColorBox:SetBackColor(currentColor);
	end
	
	self.acceptButton.Click = function(sender,args)
	  if(callback == 0) then
	     self.parent:setFervourColor(currentColor);
	  elseif(callback == 1) then
	     self.parent:setBackColor(currentColor);
	  elseif(callback == 2) then
	     self.parent:setFervourAColor(currentColor);
	  elseif(callback == 3) then
	     self.parent:setFervourFColor(currentColor);
	  elseif(callback == 4) then
	     self.parent:setFervourGColor(currentColor);
	  elseif(callback == 5) then
	     self.parent:setNumberColor(currentColor);
	  end

	  self:SetVisible(false);
	end
	
	-- have the main window close the options
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         if(parent ~= nil) then
            self.parent:CloseColorPicker();
         end
      end
   end
	
end