import "Turbine";
import "Turbine.Debug";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Utils.BitOps";

LogWindow = class(Turbine.UI.Lotro.Window);

function LogWindow:Constructor(parent, data)
	Turbine.UI.Lotro.Window.Constructor( self );
	
   -- set size of window	
	self.width = 710;
	self.height = 300;
	self.windowWidth, self.windowHeight = Turbine.UI.Display:GetSize();
	
	-- some graph base settings
	self.gLocX = 80;
	self.gLocY = 40;
	self.gWidth = 600;
	self.gHeight = 198;
	
	-- create link to parent window
	self.mainWindow = parent;
   
	-- set the default window settings
	self:SetPosition(self.windowWidth /2 - self.width/2,self.windowHeight/2 - self.height/2);	
	self:SetSize( self.width, self.height );
	self:SetBlendMode(Turbine.UI.BlendMode.Undefined);
	self:SetBackColor( Turbine.UI.Color(0.0,0,0,0) );
	self:SetText( logWindowTitleString );
	self:SetOpacity( 1 );
   self:SetVisible(true);
   
   -- setup the X labels
   self.dataLabels = { };   
   
   self:AddLabels(data);
   self:AddGraph(data);
   
   	-- have the main window close the options
   self.VisibleChanged = function(sender,args)
      if(self:IsVisible() == false) then
         if(parent ~= nil) then
            parent:CloseLog();
         end
      end
   end	
end

function LogWindow:AddLabels(data)

   if(table.getn(data) == 0) then
      Turbine.Shell.WriteLine(noDataString);
      return;
   end

   fullTime = data[table.getn(data)][1]; 
   
   -- fervour label option
   self.fervourLabel = Turbine.UI.Label();
   self.fervourLabel:SetSize(70,20);
   self.fervourLabel:SetPosition(20,130);
   self.fervourLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.fervourLabel:SetParent(self);
   self.fervourLabel:SetText(fervourString);
   self.fervourLabel:SetVisible(true);   
   
   -- time label option
   self.timeLabel = Turbine.UI.Label();
   self.timeLabel:SetSize(270,20);
   self.timeLabel:SetPosition(215,270);
   self.timeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.timeLabel:SetParent(self);
   self.timeLabel:SetText(timeString);
   self.timeLabel:SetVisible(true);
   
   -- zero fervour label option
   self.zfervourLabel = Turbine.UI.Label();
   self.zfervourLabel:SetSize(10,20);
   self.zfervourLabel:SetPosition(self.gLocX - 10,self.gLocY + 188);
   self.zfervourLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.zfervourLabel:SetParent(self);
   self.zfervourLabel:SetText("0");
   self.zfervourLabel:SetVisible(true);
   
   -- three fervour label option
   self.tfervourLabel = Turbine.UI.Label();
   self.tfervourLabel:SetSize(10,20);
   self.tfervourLabel:SetPosition(self.gLocX - 10,self.gLocY + 122);
   self.tfervourLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.tfervourLabel:SetParent(self);
   self.tfervourLabel:SetText("");
   self.tfervourLabel:SetVisible(true);
   
   -- six fervour label option
   self.sfervourLabel = Turbine.UI.Label();
   self.sfervourLabel:SetSize(10,20);
   self.sfervourLabel:SetPosition(self.gLocX - 10,self.gLocY + 56);
   self.sfervourLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.sfervourLabel:SetParent(self);
   self.sfervourLabel:SetText("");
   self.sfervourLabel:SetVisible(true);
   
   -- nine fervour label option
   self.nfervourLabel = Turbine.UI.Label();
   self.nfervourLabel:SetSize(10,20);
   self.nfervourLabel:SetPosition(self.gLocX - 10,self.gLocY - 10);
   self.nfervourLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
   self.nfervourLabel:SetParent(self);
   self.nfervourLabel:SetText("5");
   self.nfervourLabel:SetVisible(true);   
    
   -- zero time label option
   self.ztimeLabel = Turbine.UI.Label();
   self.ztimeLabel:SetSize(10,20);
   self.ztimeLabel:SetPosition(self.gLocX - 5,self.gLocY + self.gHeight);
   self.ztimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.ztimeLabel:SetParent(self);
   self.ztimeLabel:SetText("0");
   self.ztimeLabel:SetVisible(true);   
    
   -- 25% time label option
   self.atimeLabel = Turbine.UI.Label();
   self.atimeLabel:SetSize(50,20);
   self.atimeLabel:SetPosition(self.gLocX + self.gWidth * 1 / 4 - 25,self.gLocY + self.gHeight);
   self.atimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.atimeLabel:SetParent(self);
   self.atimeLabel:SetText(string.format("%.2f",fullTime * 1 / 4));
   self.atimeLabel:SetVisible(true);  
    
   -- 50% time label option
   self.btimeLabel = Turbine.UI.Label();
   self.btimeLabel:SetSize(50,20);
   self.btimeLabel:SetPosition(self.gLocX + self.gWidth * 2 / 4 - 25,self.gLocY + self.gHeight);
   self.btimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.btimeLabel:SetParent(self);
   self.btimeLabel:SetText(string.format("%.2f",fullTime * 2 / 4));
   self.btimeLabel:SetVisible(true);   
    
   -- 75% time label option
   self.ctimeLabel = Turbine.UI.Label();
   self.ctimeLabel:SetSize(50,20);
   self.ctimeLabel:SetPosition(self.gLocX + self.gWidth * 3 / 4 - 25,self.gLocY + self.gHeight);
   self.ctimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.ctimeLabel:SetParent(self);
   self.ctimeLabel:SetText(string.format("%.2f",fullTime * 3 / 4));
   self.ctimeLabel:SetVisible(true);  
    
   -- 100% time label option
   self.dtimeLabel = Turbine.UI.Label();
   self.dtimeLabel:SetSize(50,20);
   self.dtimeLabel:SetPosition(self.gLocX + self.gWidth * 4 / 4 - 25,self.gLocY + self.gHeight);
   self.dtimeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
   self.dtimeLabel:SetParent(self);
   self.dtimeLabel:SetText(string.format("%.2f",fullTime));
   self.dtimeLabel:SetVisible(true);
   
   -- add the labels for each data point
   for i,v in ipairs(data) do
   
      -- get the x location
      x = self.gLocX + self.gWidth - (((fullTime - v[1])/fullTime) * self.gWidth) - 5;
      
      -- get the y location
      y = self.gLocY + ((self.gHeight / 5) * (5 - v[2])) - 10;
         
      self.dataLabels[i] = Turbine.UI.Label();
      self.dataLabels[i]:SetSize(10,20);
      self.dataLabels[i]:SetPosition(x,y);
      self.dataLabels[i]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
      self.dataLabels[i]:SetParent(self);
      self.dataLabels[i]:SetZOrder(50);
      self.dataLabels[i]:SetText("X");
      self.dataLabels[i]:SetVisible(true);   
   end
end

function LogWindow:AddGraph(data)

   self.graphBox = Turbine.UI.Lotro.TextBox();
   self.graphBox:SetSize(self.gWidth,self.gHeight);
   self.graphBox:SetPosition(self.gLocX,self.gLocY);
   self.graphBox:SetZOrder(0);
   self.graphBox:SetParent(self);
   self.graphBox:SetReadOnly(true);
   self.graphBox:SetVisible(true);   
end